@@ -1,10 +1,14 @@
+import os
+
 import questionary
+import yaml
 from packaging.version import Version
 
-from commitizen import factory, out
-from commitizen.config import BaseConfig, IniConfig, TomlConfig
+from commitizen import cmd, factory, out
+from commitizen.__version__ import __version__
+from commitizen.config import BaseConfig, TomlConfig
 from commitizen.cz import registry
-from commitizen.defaults import long_term_support_config_files
+from commitizen.defaults import config_files
 from commitizen.exceptions import NoAnswersError
 from commitizen.git import get_latest_tag_name, get_tag_names
 
@@ -20,11 +24,8 @@ class Init:
         # No config for commitizen exist
         if not self.config.path:
             config_path = self._ask_config_path()
-
             if "toml" in config_path:
                 self.config = TomlConfig(data="", path=config_path)
-            else:
-                self.config = IniConfig(data="", path=config_path)
 
             self.config.init_empty_config_content()
 
@@ -33,17 +34,20 @@ class Init:
             values_to_add["version"] = Version(tag).public
             values_to_add["tag_format"] = self._ask_tag_format(tag)
             self._update_config_file(values_to_add)
+
+            if questionary.confirm("Do you want to install pre-commit hook?").ask():
+                self._install_pre_commit_hook()
+
             out.write("You can bump the version and create changelog running:\n")
             out.info("cz bump --changelog")
             out.success("The configuration are all set.")
         else:
-            # TODO: handle the case that config file exist but no value
             out.line(f"Config file {self.config.path} already exists")
 
     def _ask_config_path(self) -> str:
         name = questionary.select(
             "Please choose a supported config file: (default: pyproject.toml)",
-            choices=long_term_support_config_files,
+            choices=config_files,
             default="pyproject.toml",
             style=self.cz.style,
         ).ask()
@@ -101,6 +105,50 @@ class Init:
                 tag_format = "$version"
         return tag_format
 
+    def _install_pre_commit_hook(self):
+        pre_commit_config_filename = ".pre-commit-config.yaml"
+        cz_hook_config = {
+            "repo": "https://github.com/commitizen-tools/commitizen",
+            "rev": f"v{__version__}",
+            "hooks": [{"id": "commitizen", "stages": ["commit-msg"]}],
+        }
+
+        config_data = {}
+        if not os.path.isfile(pre_commit_config_filename):
+            # .pre-commit-config does not exist
+            config_data["repos"] = [cz_hook_config]
+        else:
+            # breakpoint()
+            with open(pre_commit_config_filename) as config_file:
+                yaml_data = yaml.safe_load(config_file)
+                if yaml_data:
+                    config_data = yaml_data
+
+            if "repos" in config_data:
+                for pre_commit_hook in config_data["repos"]:
+                    if "commitizen" in pre_commit_hook["repo"]:
+                        out.write("commitizen already in pre-commit config")
+                        break
+                else:
+                    config_data["repos"].append(cz_hook_config)
+            else:
+                # .pre-commit-config exists but there's no "repos" key
+                config_data["repos"] = [cz_hook_config]
+
+        with open(pre_commit_config_filename, "w") as config_file:
+            yaml.safe_dump(config_data, stream=config_file)
+
+        c = cmd.run("pre-commit install --hook-type commit-msg")
+        if c.return_code == 127:
+            out.error(
+                "pre-commit is not installed in current environement.\n"
+                "Run 'pre-commit install --hook-type commit-msg' again after it's installed"
+            )
+        elif c.return_code != 0:
+            out.error(c.err)
+        else:
+            out.write("commitizen pre-commit hook is now installed in your '.git'\n")
+
     def _update_config_file(self, values):
         for key, value in values.items():
             self.config.set_key(key, value)
